@@ -19,6 +19,7 @@ from docutils.parsers import rst
 from seqdiag import parser
 from seqdiag.builder import ScreenNodeBuilder
 from seqdiag.drawer import DiagramDraw
+from seqdiag.utils.rst.nodes import seqdiag
 from blockdiag.utils.rst import directives
 
 
@@ -33,10 +34,6 @@ directive_options_default = dict(format='PNG',
 directive_options = {}
 
 
-class seqdiag(nodes.General, nodes.Element):
-    pass
-
-
 class SeqdiagDirectiveBase(directives.BlockdiagDirectiveBase):
     """ Directive to insert arbitrary dot markup. """
     name = "seqdiag"
@@ -56,6 +53,7 @@ class SeqdiagDirective(directives.BlockdiagDirective):
         return ScreenNodeBuilder.build(tree)
 
     def node2image(self, node, diagram):
+        options = node['options']
         filename = self.image_filename(node)
         fontpath = self.detectfont()
         _format = self.global_options['format'].lower()
@@ -72,10 +70,15 @@ class SeqdiagDirective(directives.BlockdiagDirective):
             content = drawer.save(None)
 
             if _format == 'svg' and self.global_options['inline_svg'] is True:
+                size = drawer.pagesize()
+                if 'maxwidth' in options and options['maxwidth'] < size[0]:
+                    ratio = float(options['maxwidth']) / size[0]
+                    new_size = (options['maxwidth'], int(size[1] * ratio))
+                    content = drawer.save(new_size)
+
                 return nodes.raw('', content.decode('utf-8'), format='html')
 
         size = drawer.pagesize()
-        options = node['options']
         if 'maxwidth' in options and options['maxwidth'] < size[0]:
             ratio = float(options['maxwidth']) / size[0]
             thumb_size = (options['maxwidth'], size[1] * ratio)
